@@ -1,20 +1,22 @@
 # -*- coding: utf-8 -*-
 
-"""This module provides high-level classes to open and read DarwinCore Archive."""
+"""High-level classes to open and read DarwinCore Archive."""
 
 import os
-import zipfile
 import tarfile
-from tempfile import mkdtemp
-from shutil import rmtree
-from errno import ENOENT
-
 import xml.etree.ElementTree as ET
+import zipfile
+from errno import ENOENT
+from shutil import rmtree
+from tempfile import mkdtemp
+from typing import List, Optional, Dict, Any, IO
+from xml.etree.ElementTree import Element
 
-from dwca.files import CSVDataFile
+import dwca.vendor
 from dwca.descriptors import ArchiveDescriptor, DataFileDescriptor, shorten_term
 from dwca.exceptions import RowNotFound, InvalidArchive, InvalidSimpleArchive, NotADataFile
-import dwca.vendor
+from dwca.files import CSVDataFile
+from dwca.rows import CoreRow
 
 
 class DwCAReader(object):
@@ -64,7 +66,7 @@ class DwCAReader(object):
 
     """
 
-    default_metadata_filename  = "EML.xml"
+    default_metadata_filename = "EML.xml"
     default_metafile_name = "meta.xml"
     source_metadata_directory = 'dataset'
 
@@ -75,31 +77,33 @@ class DwCAReader(object):
         self.close()
 
     def __init__(self, path, extensions_to_ignore=None):
+        # type: (str, List[str]) -> None
         """Open the Darwin Core Archive."""
         if extensions_to_ignore is None:
             extensions_to_ignore = []
 
         #: The path to the Darwin Core Archive file, as passed to the constructor.
-        self.archive_path = path
+        self.archive_path = path  # type: str
 
         if os.path.isdir(self.archive_path):  # Archive is a (directly readable) directory
-            self._workin_directory_path = self.archive_path
-            self._directory_to_clean = None
+            self._working_directory_path = self.archive_path
+            self._directory_to_clean = None  # type: Optional[str]
         else:  # Archive is zipped/tgzipped, we have to extract it first.
-            self._directory_to_clean, self._workin_directory_path = self._extract()
+            self._directory_to_clean, self._working_directory_path = self._extract()
 
         #: An :class:`descriptors.ArchiveDescriptor` instance giving access to the archive
         #: descriptor/metafile (``meta.xml``)
+        self.descriptor = None  # type: Optional[ArchiveDescriptor]
         try:
             self.descriptor = ArchiveDescriptor(self.open_included_file(self.default_metafile_name).read(),
                                                 files_to_ignore=extensions_to_ignore)
         except IOError as exc:
             if exc.errno == ENOENT:
-                self.descriptor = None
+                pass
 
         #: A :class:`xml.etree.ElementTree.Element` instance containing the (scientific) metadata
         #: of the archive, or `None` if the archive has no metadata.
-        self.metadata = self._parse_metadata_file()
+        self.metadata = self._parse_metadata_file()  # type: Optional[Element]
 
         #: If the archive contains source-level metadata (typically, GBIF downloads), this is a dict such as::
         #:
@@ -107,23 +111,24 @@ class DwCAReader(object):
         #:       'dataset2_UUID': <dataset2 EML> (xml.etree.ElementTree.Element object), ...}
         #:
         #: See :doc:`gbif_results` for more details.
-        self.source_metadata = self._get_source_metadata()
+        self.source_metadata = self._get_source_metadata()  # type: Dict[str, Element]
 
         if self.descriptor:  # We have an Archive descriptor that we can use to access data files.
             #: An instance of :class:`dwca.files.CSVDataFile` for the core data file.
-            self.core_file = CSVDataFile(self._workin_directory_path, self.descriptor.core)
+            self.core_file = CSVDataFile(self._working_directory_path, self.descriptor.core)  # type: CSVDataFile
 
             #: A list of :class:`dwca.files.CSVDataFile`, one entry for each extension data file , sorted by order of
             #: appearance in the Metafile (or an empty list if the archive doesn't use extensions).
-            self.extension_files = [CSVDataFile(work_directory=self._workin_directory_path,
+            self.extension_files = [CSVDataFile(work_directory=self._working_directory_path,
                                                 file_descriptor=d)
-                                    for d in self.descriptor.extensions]
+                                    for d in self.descriptor.extensions]  # type: List[CSVDataFile]
         else:  # Archive without descriptor, we'll have to find and inspect the data file
             try:
                 datafile_name = self._is_valid_simple_archive()
-                descriptor = DataFileDescriptor.make_from_file(os.path.join(self._workin_directory_path, datafile_name))
+                descriptor = DataFileDescriptor.make_from_file(
+                    os.path.join(self._working_directory_path, datafile_name))
 
-                self.core_file = CSVDataFile(work_directory=self._workin_directory_path,
+                self.core_file = CSVDataFile(work_directory=self._working_directory_path,
                                              file_descriptor=descriptor)
                 self.extension_files = []
             except InvalidSimpleArchive:
@@ -131,8 +136,9 @@ class DwCAReader(object):
                 raise InvalidSimpleArchive(msg)
 
     def _get_source_metadata(self):
-        source_metadata = {}
-        source_metadata_dir = os.path.join(self._workin_directory_path, self.source_metadata_directory)
+        # type: () -> Dict[str, Element]
+        source_metadata = {}  # type: Dict[str, Element]
+        source_metadata_dir = os.path.join(self._working_directory_path, self.source_metadata_directory)
 
         if os.path.isdir(source_metadata_dir):
             for f in os.listdir(source_metadata_dir):
@@ -143,6 +149,15 @@ class DwCAReader(object):
 
         return source_metadata
 
+    @property
+    def core_file_location(self):
+        # type: () -> str
+        """The (relative) path to the core data file.
+
+        Example: `'occurrence.txt'`
+        """
+        return self.core_file.file_descriptor.file_location
+
     def pd_read(self, relative_path, **kwargs):
         """Return a `Pandas <https://pandas.pydata.org>`_ \
         `DataFrame <https://pandas.pydata.org/pandas-docs/stable/generated/pandas.DataFrame.html>`_ for the data file \
@@ -168,10 +183,7 @@ class DwCAReader(object):
             Default values of Darwin Core Archive are supported: A column will be added to the DataFrame if a term has
             a default value in the Metafile (but no corresponding column in the CSV Data File).
         """
-        datafile_descriptor = self.get_descriptor_for(relative_path)
-
-        if datafile_descriptor is None:
-            raise NotADataFile()
+        datafile_descriptor = self.get_descriptor_for(relative_path)  # type: DataFileDescriptor
 
         if not dwca.vendor._has_pandas:
             raise ImportError("Pandas is missing.")
@@ -194,6 +206,7 @@ class DwCAReader(object):
         return df
 
     def orphaned_extension_rows(self):
+        # type: () -> Dict[str, Dict[str, List[int]]]
         """Return a dict of the orphaned extension rows.
 
         Orphaned extension rows are extension rows who reference non-existing core rows. This methods returns a dict
@@ -227,12 +240,14 @@ class DwCAReader(object):
 
     @property
     def use_extensions(self):
+        # type: () -> bool
         """`True` if the archive makes use of extensions."""
-        return (self.descriptor is not None) and self.descriptor.extensions
+        return self.descriptor and len(self.descriptor.extensions) > 0
 
     @property
     # TODO: decide, test and document what we guarantee about ordering
     def rows(self):
+        # type: () -> List[CoreRow]
         """A list of :class:`rows.CoreRow` objects representing the content of the archive.
 
         .. warning::
@@ -243,6 +258,7 @@ class DwCAReader(object):
         return list(self)
 
     def get_corerow_by_id(self, row_id):
+        # type: (str) -> CoreRow
         """Return the (core) row whose ID is `row_id`.
 
         :param row_id: ID of the core row you want
@@ -267,6 +283,7 @@ class DwCAReader(object):
         raise RowNotFound
 
     def get_row_by_id(self, row_id):
+        # type: (str) -> CoreRow
         """
         .. warning::
 
@@ -278,6 +295,7 @@ class DwCAReader(object):
         return self.get_corerow_by_id(row_id)
 
     def get_corerow_by_position(self, position):
+        # type: (int) -> CoreRow
         """Return a core row according to its position/index in core file.
 
         :param position: the position (starting at 0) of the row you want in the core file.
@@ -299,6 +317,7 @@ class DwCAReader(object):
         raise RowNotFound
 
     def get_row_by_index(self, index):
+        # type: (int) -> CoreRow
         """
         .. warning::
 
@@ -310,6 +329,7 @@ class DwCAReader(object):
         return self.get_corerow_by_position(index)
 
     def absolute_temporary_path(self, relative_path):
+        # type: (str) -> str
         """Return the absolute path of a file located within the archive.
 
         This method allows raw access to the files contained in the archive. It can be useful to open additional, \
@@ -332,9 +352,10 @@ class DwCAReader(object):
             File existence is not tested.
 
         """
-        return os.path.abspath(os.path.join(self._workin_directory_path, relative_path))
+        return os.path.abspath(os.path.join(self._working_directory_path, relative_path))
 
     def get_descriptor_for(self, relative_path):
+        # type: (str) -> DataFileDescriptor
         """Return a descriptor for the data file located at relative_path.
 
         :param relative_path: the path (relative to the archive root) to the data file you want info about.
@@ -357,22 +378,24 @@ class DwCAReader(object):
         raise NotADataFile("{fn} is not a data file".format(fn=relative_path))
 
     def _is_valid_simple_archive(self):
+        # type: () -> str
         # If the working dir appear to contains a valid simple darwin core archive
         # (one single data file + possibly some metadata), returns the name of the data file.
         #
         # Otherwise, throws an InvalidSimpleArchive exception.
-        _, _, files = next(os.walk(self._workin_directory_path))
+        _, _, files = next(os.walk(self._working_directory_path))
 
-        if len(files) == 1:  # We found a single file
-            return files[0]
+        if len(files) == 1:
+            return files[0]  # A single file, so that's the one
         elif len(files) == 2:
             # Two files found: if one of them is EML.xml, the other is considered as the data file
             if self.default_metadata_filename in files:
-                return [f for f in files if f is not self.default_metadata_filename][0]
+                return [f for f in files if f != self.default_metadata_filename][0]
 
         raise InvalidSimpleArchive()
 
     def open_included_file(self, relative_path, *args, **kwargs):
+        # type: (str, Any, Any) -> IO
         """Simple wrapper around Python's build-in `open` function.
 
         To be used only for reading.
@@ -384,10 +407,11 @@ class DwCAReader(object):
         return open(self.absolute_temporary_path(relative_path), *args, **kwargs)
 
     def _parse_metadata_file(self):
+        # type: () -> Optional[Element]
         """Load the archive (scientific) Metadata file, parse it with\
         ElementTree and return its content (or `None` if the archive has no metadata).
 
-        :raises: :class:`dwca.exceptions.InvalidArchive` if the archive references an inexisting
+        :raises: :class:`dwca.exceptions.InvalidArchive` if the archive references an non-existent
         metadata file.
         """
         # If the archive has descriptor, look for the metadata filename there.
@@ -404,15 +428,19 @@ class DwCAReader(object):
         else:  # Otherwise, the metadata file has to be named 'EML.xml'
             try:
                 return self._parse_xml_included_file(self.default_metadata_filename)
-            except IOError as e:
-                if e.errno == ENOENT:  # File not found, this is an archive without metadata
+            except IOError as exc:
+                if exc.errno == ENOENT:  # File not found, this is an archive without metadata
                     return None
 
+        assert False  # For MyPy, see: https://github.com/python/mypy/issues/4223#issuecomment-342865133
+
     def _parse_xml_included_file(self, relative_path):
+        # type: (str) -> Element
         """Load, parse and returns (as ElementTree.Element) XML file located at relative_path."""
         return ET.parse(self.absolute_temporary_path(relative_path)).getroot()
 
     def _unzip_or_untar(self):
+        # type: () -> str
         """Create a temporary dir. and uncompress/unarchive self.archive_path there.
 
         Returns the path to that temporary directory.
@@ -451,7 +479,7 @@ class DwCAReader(object):
         else:
             content_dir = extracted_dir
 
-        return (extracted_dir, content_dir)
+        return extracted_dir, content_dir
 
     def close(self):
         """Close the Darwin Core Archive and remove temporary/working files.
@@ -467,12 +495,10 @@ class DwCAReader(object):
             extension_file.close()
 
         if self._directory_to_clean:
-            self._cleanup_temporary_dir()
-
-    def _cleanup_temporary_dir(self):
-        rmtree(self._directory_to_clean, False)
+            rmtree(self._directory_to_clean, False)
 
     def core_contains_term(self, term_url):
+        # type: (str) -> bool
         """Return `True` if the Core file of the archive contains the `term_url` term."""
         return term_url in self.core_file.file_descriptor.terms
 
@@ -484,16 +510,17 @@ class DwCAReader(object):
         return self.next()
 
     def next(self):  # NOQA
-        r = self.core_file.get_row_by_position(self._corefile_pointer)
-        if r:
+        try:
+            row = self.core_file.get_row_by_position(self._corefile_pointer)
+
             # Set up linked data so the CoreRow will know about them
-            r.link_extension_files(self.extension_files)
-            r.link_source_metadata(self.source_metadata)
+            row.link_extension_files(self.extension_files)
+            row.link_source_metadata(self.source_metadata)
 
             self._corefile_pointer = self._corefile_pointer + 1
-            return r
-
-        raise StopIteration
+            return row
+        except IndexError:
+            raise StopIteration
 
 
 class GBIFResultsReader(DwCAReader):
