@@ -1,33 +1,22 @@
 # -*- coding: utf-8 -*-
 
-import sys
-import unittest
 import os
+import sys
 import tempfile
+import unittest
 import warnings
-
 import xml.etree.ElementTree as ET
 
+import pandas as pd
 from mock import patch
 
-import pandas as pd
-
+from dwca.darwincore.utils import qualname as qn
+from dwca.descriptors import ArchiveDescriptor, DataFileDescriptor
+from dwca.exceptions import RowNotFound, InvalidArchive, NotADataFile
 from dwca.files import CSVDataFile
 from dwca.read import DwCAReader, GBIFResultsReader
 from dwca.rows import CoreRow, ExtensionRow
-from dwca.darwincore.utils import qualname as qn
-from dwca.exceptions import RowNotFound, InvalidArchive, NotADataFile
-from dwca.descriptors import ArchiveDescriptor, DataFileDescriptor
-
-from .helpers import (GBIF_RESULTS_PATH, BASIC_ARCHIVE_PATH, EXTENSION_ARCHIVE_PATH,
-                      MULTIEXTENSIONS_ARCHIVE_PATH, NOHEADERS1_PATH, NOHEADERS2_PATH,
-                      IDS_ARCHIVE_PATH, DEFAULT_VAL_PATH, UTF8EOL_ARCHIVE_PATH,
-                      DIRECTORY_ARCHIVE_PATH, DIRECTORY_CSV_QUOTE_ARCHIVE_PATH, DEFAULT_META_VALUES,
-                      INVALID_LACKS_METADATA, SUBDIR_ARCHIVE_PATH, SIMPLE_CSV, SIMPLE_CSV_EML,
-                      SIMPLE_CSV_DOS, BASIC_ENCLOSED_ARCHIVE_PATH, INVALID_SIMPLE_TOOMUCH,
-                      INVALID_SIMPLE_TWO, SIMPLE_CSV_NOTENCLOSED, NOMETADATA_PATH,
-                      DEFAULT_METADATA_FILENAME, BASIC_ARCHIVE_TGZ_PATH, INVALID_DESCRIPTOR,
-                      DWCA_ORPHANED_ROWS, METADATA_1252_ENCODING)
+from .helpers import sample_data_path
 
 
 class TestPandasIntegration(unittest.TestCase):
@@ -36,12 +25,12 @@ class TestPandasIntegration(unittest.TestCase):
 
     @patch('dwca.vendor._has_pandas', False)
     def test_pd_read_pandas_unavailable(self):
-        with DwCAReader(BASIC_ARCHIVE_PATH) as dwca:
+        with DwCAReader(sample_data_path('dwca-simple-test-archive.zip')) as dwca:
             with self.assertRaises(ImportError):
                 dwca.pd_read('occurrence.txt')
 
     def test_pd_read_simple_case(self):
-        with DwCAReader(BASIC_ARCHIVE_PATH) as dwca:
+        with DwCAReader(sample_data_path('dwca-simple-test-archive.zip')) as dwca:
             df = dwca.pd_read('occurrence.txt')
 
             # check types, headers and dimensions
@@ -57,7 +46,7 @@ class TestPandasIntegration(unittest.TestCase):
             self.assertEqual(df['scientificName'].values.tolist(), ['tetraodon fluviatilis', 'betta splendens'])
 
     def test_pd_read_no_data_files(self):
-        with DwCAReader(BASIC_ARCHIVE_PATH) as dwca:
+        with DwCAReader(sample_data_path('dwca-simple-test-archive.zip')) as dwca:
             with self.assertRaises(NotADataFile):
                 dwca.pd_read('imaginary_file.txt')
 
@@ -65,7 +54,7 @@ class TestPandasIntegration(unittest.TestCase):
                 dwca.pd_read('eml.xml')
 
     def test_pd_read_extensions(self):
-        with DwCAReader(MULTIEXTENSIONS_ARCHIVE_PATH) as dwca:
+        with DwCAReader(sample_data_path('dwca-2extensions.zip')) as dwca:
             desc_df = dwca.pd_read('description.txt')
             self.assertIsInstance(desc_df, pd.DataFrame)
             self.assertEqual(desc_df.shape, (3, 4))
@@ -77,14 +66,14 @@ class TestPandasIntegration(unittest.TestCase):
             self.assertEqual(vern_df['countryCode'].values.tolist(), ['US', 'ZA', 'FI', 'ZA'])
 
     def test_pd_read_quotedir(self):
-        with DwCAReader(DIRECTORY_CSV_QUOTE_ARCHIVE_PATH) as dwca:
+        with DwCAReader(sample_data_path('dwca-csv-quote-dir')) as dwca:
             df = dwca.pd_read('occurrence.txt')
             # The field separator is found in a quoted field, don't break
             self.assertEqual(df.shape, (2, 5))
             self.assertEqual(df['basisOfRecord'].values.tolist()[0], 'Observation, something')
 
     def test_pd_read_default_values(self):
-        with DwCAReader(DEFAULT_VAL_PATH) as dwca:
+        with DwCAReader(sample_data_path('dwca-test-default.zip')) as dwca:
             df = dwca.pd_read('occurrence.txt')
 
             self.assertIn('country', df.columns.values.tolist())
@@ -96,14 +85,14 @@ class TestPandasIntegration(unittest.TestCase):
 
         (only the EOL string specified in meta.xml should be used).
          """
-        with DwCAReader(UTF8EOL_ARCHIVE_PATH) as dwca:
+        with DwCAReader(sample_data_path('dwca-utf8-eol-test.zip')) as dwca:
             df = dwca.pd_read('occurrence.txt')
             # If line properly split => 64 columns.
             # (61 - and probably an IndexError - if errors)
             self.assertEqual(64, df.shape[1])
 
     def test_pd_read_simple_csv(self):
-        with DwCAReader(SIMPLE_CSV) as dwca:
+        with DwCAReader(sample_data_path('dwca-simple-csv.zip')) as dwca:
 
             df = dwca.pd_read('0008333-160118175350007.csv')
             # Ensure we get the correct number of rows
@@ -112,22 +101,30 @@ class TestPandasIntegration(unittest.TestCase):
 
             self.assertEqual(df['decimallatitude'].values.tolist()[1], -31.98333)
 
+
 class TestDwCAReader(unittest.TestCase):
     # TODO: Move row-oriented tests to another test class
     """Unit tests for DwCAReader class."""
+    def test_core_file_location(self):
+        with DwCAReader(sample_data_path('dwca-simple-test-archive.zip')) as dwca:
+            self.assertEqual(dwca.core_file_location, 'occurrence.txt')
+
+        with DwCAReader(sample_data_path('dwca-simple-csv.zip')) as dwca:
+            self.assertEqual(dwca.core_file_location, '0008333-160118175350007.csv')
+
     def test_core_file(self):
-        with DwCAReader(BASIC_ARCHIVE_PATH) as dwca:
+        with DwCAReader(sample_data_path('dwca-simple-test-archive.zip')) as dwca:
             self.assertIsInstance(dwca.core_file, CSVDataFile)
 
             # Quick content check just to be sure
             self.assertEqual(dwca.core_file.lines_to_ignore, 1)
 
     def test_extension_file_noext(self):
-        with DwCAReader(BASIC_ARCHIVE_PATH) as dwca:
+        with DwCAReader(sample_data_path('dwca-simple-test-archive.zip')) as dwca:
             self.assertEqual(dwca.extension_files, [])
 
     def test_extension_files(self):
-        with DwCAReader(MULTIEXTENSIONS_ARCHIVE_PATH) as dwca:
+        with DwCAReader(sample_data_path('dwca-2extensions.zip')) as dwca:
             # Check extension_files is iterable and contains the right type
             for ext in dwca.extension_files:
                 self.assertIsInstance(ext, CSVDataFile)
@@ -140,7 +137,7 @@ class TestDwCAReader(unittest.TestCase):
             self.assertEqual(dwca.extension_files[1].file_descriptor.file_location, 'vernacularname.txt')
 
     def test_get_descriptor_for(self):
-        with DwCAReader(MULTIEXTENSIONS_ARCHIVE_PATH) as dwca:
+        with DwCAReader(sample_data_path('dwca-2extensions.zip')) as dwca:
             # We can get a DataFileDescriptor for each data file
             self.assertIsInstance(dwca.get_descriptor_for('taxon.txt'), DataFileDescriptor)
             self.assertIsInstance(dwca.get_descriptor_for('description.txt'), DataFileDescriptor)
@@ -175,13 +172,13 @@ class TestDwCAReader(unittest.TestCase):
             self.assertEqual(vernacular_descriptor.type, 'http://rs.gbif.org/terms/1.0/VernacularName')
 
         # Also check we can get a DataFileDescriptor for a simple Archive (without metafile)
-        with DwCAReader(SIMPLE_CSV) as dwca:
+        with DwCAReader(sample_data_path('dwca-simple-csv.zip')) as dwca:
             self.assertIsInstance(dwca.get_descriptor_for('0008333-160118175350007.csv'), DataFileDescriptor)
 
     def test_open_included_file(self):
         """Ensure DwCAReader.open_included_file work as expected."""
         # Let's use it to read the raw core data file:
-        with DwCAReader(DIRECTORY_ARCHIVE_PATH) as dwca:
+        with DwCAReader(sample_data_path('dwca-simple-dir')) as dwca:
             f = dwca.open_included_file('occurrence.txt')
 
             raw_occ = f.read()
@@ -194,28 +191,28 @@ class TestDwCAReader(unittest.TestCase):
 
         This ensure cases like http://dev.gbif.org/issues/browse/PF-2470 (descriptor contains
         <field index="234" term="http://rs.gbif.org/terms/1.0/lastCrawled"/>, but has only 234
-        fields in data file) fail in a visible way (previously, archive just appeard empty).
+        fields in data file) fail in a visible way (previously, archive just appeared empty).
         """
-        with DwCAReader(INVALID_DESCRIPTOR) as dwca:
+        with DwCAReader(sample_data_path('dwca-malformed-descriptor')) as dwca:
             with self.assertRaises(InvalidArchive):
                 for _ in dwca:
                     pass
 
     def test_use_extensions(self):
         """Ensure the .use_extensions attribute of DwCAReader works as intended."""
-        with DwCAReader(BASIC_ARCHIVE_PATH) as dwca:
+        with DwCAReader(sample_data_path('dwca-simple-test-archive.zip')) as dwca:
             self.assertFalse(dwca.use_extensions)  # Basic archive without extensions
 
-        with DwCAReader(SIMPLE_CSV) as dwca:  # Just a CSV file, so no extensions
+        with DwCAReader(sample_data_path('dwca-simple-csv.zip')) as dwca:  # Just a CSV file, so no extensions
             self.assertFalse(dwca.use_extensions)
 
-        with DwCAReader(EXTENSION_ARCHIVE_PATH) as dwca:
+        with DwCAReader(sample_data_path('dwca-star-test-archive.zip')) as dwca:
             self.assertTrue(dwca.use_extensions)
 
-        with DwCAReader(MULTIEXTENSIONS_ARCHIVE_PATH) as dwca:
+        with DwCAReader(sample_data_path('dwca-2extensions.zip')) as dwca:
             self.assertTrue(dwca.use_extensions)
 
-        with DwCAReader(EXTENSION_ARCHIVE_PATH, extensions_to_ignore="vernacularname.txt") as dwca:
+        with DwCAReader(sample_data_path('dwca-star-test-archive.zip'), extensions_to_ignore="vernacularname.txt") as dwca:
             # We ignore the extension, so archive appears without
             self.assertFalse(dwca.use_extensions)
 
@@ -224,7 +221,7 @@ class TestDwCAReader(unittest.TestCase):
 
         Metadata is named "EML.xml", but no metadata attribute in Metafile.
         """
-        with DwCAReader(DEFAULT_METADATA_FILENAME) as dwca:
+        with DwCAReader(sample_data_path('dwca-default-metadata-filename.zip')) as dwca:
             self.assertIsInstance(dwca.metadata, ET.Element)
 
             v = (dwca.metadata.find('dataset')
@@ -238,7 +235,7 @@ class TestDwCAReader(unittest.TestCase):
         tmp_dir = tempfile.gettempdir()
 
         num_files_before = len(os.listdir(tmp_dir))
-        with DwCAReader(SUBDIR_ARCHIVE_PATH) as dwca:
+        with DwCAReader(sample_data_path('dwca-simple-subdir.zip')) as dwca:
             # Ensure we have access to metadata
             self.assertIsInstance(dwca.metadata, ET.Element)
 
@@ -262,7 +259,7 @@ class TestDwCAReader(unittest.TestCase):
         # Sometimes, the archive metafile references a metadata file that's not present in the
         # archive. See for example http://dev.gbif.org/issues/browse/PF-2125
         with self.assertRaises(InvalidArchive) as cm:
-            a = DwCAReader(INVALID_LACKS_METADATA)
+            a = DwCAReader(sample_data_path('dwca-invalid-lacks-metadata'))
             a.close()
 
         the_exception = cm.exception
@@ -272,8 +269,7 @@ class TestDwCAReader(unittest.TestCase):
 
     def test_implicit_encoding_metadata(self):
         """If the metadata file doesn't specifies encoding, use UTF-8."""
-
-        with DwCAReader(DIRECTORY_ARCHIVE_PATH) as dwca:
+        with DwCAReader(sample_data_path('dwca-simple-dir')) as dwca:
             v = (dwca.metadata.find('dataset').find('creator').find('individualName')
                  .find('surName').text)
             self.assertEqual(v, u'Noé')
@@ -281,7 +277,7 @@ class TestDwCAReader(unittest.TestCase):
     def test_explicit_encoding_metadata(self):
         """If the metadata file explicitly specifies encoding (<xml ...>), make sure it is used."""
 
-        with DwCAReader(METADATA_1252_ENCODING) as dwca:
+        with DwCAReader(sample_data_path('dwca-metadata-windows1252-encoding')) as dwca:
             v = (dwca.metadata.find('dataset').find('creator').find('individualName')
                  .find('surName').text)
             self.assertEqual(v, u'Noé')  # Is the accent properly interpreted?
@@ -296,11 +292,11 @@ class TestDwCAReader(unittest.TestCase):
         # There's a random file (in addition to data and EML.xml) in this one, so we can't choose
         # which file is the datafile.
         with self.assertRaises(InvalidArchive):
-            a = DwCAReader(INVALID_SIMPLE_TOOMUCH)
+            a = DwCAReader(sample_data_path('dwca-invalid-simple-toomuch.zip'))
             a.close()
 
         with self.assertRaises(InvalidArchive):
-            a = DwCAReader(INVALID_SIMPLE_TWO)
+            a = DwCAReader(sample_data_path('dwca-invalid-simple-two.zip'))
             a.close()
 
     def test_default_values_metafile(self):
@@ -309,7 +305,7 @@ class TestDwCAReader(unittest.TestCase):
 
         Optional attributes tested here: linesTerminatedBy, fieldsTerminatedBy.
         """
-        with DwCAReader(DEFAULT_META_VALUES) as dwca:
+        with DwCAReader(sample_data_path('dwca-meta-default-values')) as dwca:
             # Test iterating on rows...
             for row in dwca:
                 self.assertIsInstance(row, CoreRow)
@@ -325,7 +321,7 @@ class TestDwCAReader(unittest.TestCase):
         represented in the published data. That also seems to match quite well the definition of
         Simple Darwin Core expressed as text: http://rs.tdwg.org/dwc/terms/simple/index.htm.
         """
-        with DwCAReader(SIMPLE_CSV) as dwca:
+        with DwCAReader(sample_data_path('dwca-simple-csv.zip')) as dwca:
             # Ensure we get the correct number of rows
             self.assertEqual(len(dwca.rows), 3)
             # Ensure we can access arbitrary data
@@ -336,7 +332,7 @@ class TestDwCAReader(unittest.TestCase):
             self.assertIsNone(dwca.metadata)
 
         # Let's do the same tests again but with DOS line endings in the data file
-        with DwCAReader(SIMPLE_CSV_DOS) as dwca:
+        with DwCAReader(sample_data_path('dwca-simple-csv-dos.zip')) as dwca:
             # Ensure we get the correct number of rows
             self.assertEqual(len(dwca.rows), 3)
             # Ensure we can access arbitrary data
@@ -347,7 +343,7 @@ class TestDwCAReader(unittest.TestCase):
             self.assertIsNone(dwca.metadata)
 
         # And with a file where fields are not double quotes-enclosed:
-        with DwCAReader(SIMPLE_CSV_NOTENCLOSED) as dwca:
+        with DwCAReader(sample_data_path('dwca-simple-csv-notenclosed.zip')) as dwca:
             # Ensure we get the correct number of rows
             self.assertEqual(len(dwca.rows), 3)
             # Ensure we can access arbitrary data
@@ -358,14 +354,14 @@ class TestDwCAReader(unittest.TestCase):
             self.assertIsNone(dwca.metadata)
 
     def test_simplecsv_archive_eml(self):
-        """Test Archive witthout metafile, but containing metadata.
+        """Test Archive without metafile, but containing metadata.
 
         Similar to test_simplecsv_archive, except the archive also contains a Metadata file named
         EML.xml. This correspond to the second case on page #2 of
         http://www.gbif.org/resource/80639. The metadata file having the "standard name", it should
         properly handled.
         """
-        with DwCAReader(SIMPLE_CSV_EML) as dwca:
+        with DwCAReader(sample_data_path('dwca-simple-csv-eml.zip')) as dwca:
             # Ensure we get the correct number of rows
             self.assertEqual(len(dwca.rows), 3)
             # Ensure we can access arbitrary data
@@ -374,13 +370,12 @@ class TestDwCAReader(unittest.TestCase):
             self.assertIsNone(dwca.descriptor)
             # (scientific) metadata is found
             self.assertIsInstance(dwca.metadata, ET.Element)
-            # TODO: also access a metadata element to ensure this really works?
-            v = (dwca.metadata.find('dataset').find('language').text)
-            self.assertEqual(v, 'en')
+            # Quick content check
+            self.assertEqual(dwca.metadata.find('dataset').find('language').text, 'en')
 
     def test_unzipped_archive(self):
         """Ensure it works with non-zipped (directory) archives."""
-        with DwCAReader(DIRECTORY_ARCHIVE_PATH) as dwca:
+        with DwCAReader(sample_data_path('dwca-simple-dir')) as dwca:
             # See metadata access works...
             self.assertIsInstance(dwca.metadata, ET.Element)
 
@@ -390,14 +385,14 @@ class TestDwCAReader(unittest.TestCase):
 
     def test_csv_quote_dir_archive(self):
         """If the field separator is in a quoted field, don't break on it."""
-        with DwCAReader(DIRECTORY_CSV_QUOTE_ARCHIVE_PATH) as dwca:
+        with DwCAReader(sample_data_path('dwca-csv-quote-dir')) as dwca:
             rows = list(dwca)
             self.assertEqual(len(rows), 2)
             self.assertEqual(rows[0].data[qn('basisOfRecord')], 'Observation, something')
 
     def test_dont_enclose_unenclosed(self):
         """If fields_enclosed_by is set to an empty string, don't enclose (even if quotes are present)"""
-        with DwCAReader(DIRECTORY_ARCHIVE_PATH) as dwca:
+        with DwCAReader(sample_data_path('dwca-simple-dir')) as dwca:
             rows = list(dwca)
 
             self.assertEqual('"betta" splendens', rows[2].data[qn('scientificName')])
@@ -405,7 +400,7 @@ class TestDwCAReader(unittest.TestCase):
 
     def test_tgz_archives(self):
         """Ensure the reader (basic features) works with a .tgz Archive."""
-        with DwCAReader(BASIC_ARCHIVE_TGZ_PATH) as dwca:
+        with DwCAReader(sample_data_path('dwca-simple-test-archive.tgz')) as dwca:
             self.assertIsInstance(dwca.metadata, ET.Element)
 
             for row in dwca:
@@ -418,16 +413,16 @@ class TestDwCAReader(unittest.TestCase):
 
     def test_classic_opening(self):
         """Ensure it also works w/o the 'with' statement."""
-        dwca = DwCAReader(BASIC_ARCHIVE_PATH)
+        dwca = DwCAReader(sample_data_path('dwca-simple-test-archive.zip'))
         self.assertIsInstance(dwca.metadata, ET.Element)
         dwca.close()
 
     def test_descriptor(self):
-        with DwCAReader(BASIC_ARCHIVE_PATH) as basic_dwca:
+        with DwCAReader(sample_data_path('dwca-simple-test-archive.zip')) as basic_dwca:
             self.assertIsInstance(basic_dwca.descriptor, ArchiveDescriptor)
 
     def test_row_human_representation(self):
-        with DwCAReader(BASIC_ARCHIVE_PATH) as basic_dwca:
+        with DwCAReader(sample_data_path('dwca-simple-test-archive.zip')) as basic_dwca:
             l = basic_dwca.rows[0]
             l_repr = str(l)
             self.assertIn("Rowtype: http://rs.tdwg.org/dwc/terms/Occurrence", l_repr)
@@ -443,7 +438,7 @@ class TestDwCAReader(unittest.TestCase):
                 self.assertIn("http://rs.tdwg.org/dwc/terms/scientificName': 'tetraodon fluviatilis'",
                               l_repr)
 
-        with DwCAReader(EXTENSION_ARCHIVE_PATH) as star_dwca:
+        with DwCAReader(sample_data_path('dwca-star-test-archive.zip')) as star_dwca:
             l = star_dwca.rows[0]
             l_repr = str(l)
             self.assertIn("Rowtype: http://rs.tdwg.org/dwc/terms/Taxon", l_repr)
@@ -460,7 +455,7 @@ class TestDwCAReader(unittest.TestCase):
             self.assertIn("Reference extension rows: No", extension_l_repr)
             self.assertIn("Reference source metadata: No", extension_l_repr)
 
-        with GBIFResultsReader(GBIF_RESULTS_PATH) as gbif_dwca:
+        with GBIFResultsReader(sample_data_path('gbif-results.zip')) as gbif_dwca:
             l = gbif_dwca.rows[0]
             l_repr = str(l)
 
@@ -470,7 +465,7 @@ class TestDwCAReader(unittest.TestCase):
 
     def test_absolute_temporary_path(self):
         """Test the absolute_temporary_path() method."""
-        with DwCAReader(BASIC_ARCHIVE_PATH) as dwca:
+        with DwCAReader(sample_data_path('dwca-simple-test-archive.zip')) as dwca:
             path_to_occ = dwca.absolute_temporary_path('occurrence.txt')
 
             # Is it absolute ?
@@ -483,7 +478,7 @@ class TestDwCAReader(unittest.TestCase):
             self.assertTrue(content.startswith("id"))
             f.close()
 
-        with DwCAReader(DIRECTORY_ARCHIVE_PATH) as dwca:
+        with DwCAReader(sample_data_path('dwca-simple-dir')) as dwca:
             # Also check if the archive is a directory
             path_to_occ = dwca.absolute_temporary_path('occurrence.txt')
 
@@ -500,7 +495,7 @@ class TestDwCAReader(unittest.TestCase):
         """Test no temporary files are left after execution (using 'with' statement)."""
         num_files_before = len(os.listdir('.'))
 
-        with DwCAReader(BASIC_ARCHIVE_PATH):
+        with DwCAReader(sample_data_path('dwca-simple-test-archive.zip')):
             pass
 
         num_files_after = len(os.listdir('.'))
@@ -511,7 +506,7 @@ class TestDwCAReader(unittest.TestCase):
         """If the source is already a directory, there's nothing to create nor cleanup."""
         num_files_before = len(os.listdir('.'))
 
-        with DwCAReader(DIRECTORY_ARCHIVE_PATH):
+        with DwCAReader(sample_data_path('dwca-simple-dir')):
             pass
 
         num_files_after = len(os.listdir('.'))
@@ -521,7 +516,7 @@ class TestDwCAReader(unittest.TestCase):
         """Test no temporary files are left after execution (calling close() manually)."""
         num_files_before = len(os.listdir('.'))
 
-        r = DwCAReader(BASIC_ARCHIVE_PATH)
+        r = DwCAReader(sample_data_path('dwca-simple-test-archive.zip'))
         r.close()
 
         num_files_after = len(os.listdir('.'))
@@ -533,11 +528,11 @@ class TestDwCAReader(unittest.TestCase):
 
         (check that the cleanup routine for zipped file is not called by accident)
         """
-        r = DwCAReader(DIRECTORY_ARCHIVE_PATH)
+        r = DwCAReader(sample_data_path('dwca-simple-dir'))
         r.close()
 
         # If previously destroyed, this will fail...
-        r = DwCAReader(DIRECTORY_ARCHIVE_PATH)
+        r = DwCAReader(sample_data_path('dwca-simple-dir'))
         self.assertIsInstance(r.metadata, ET.Element)
         r.close()
 
@@ -549,7 +544,7 @@ class TestDwCAReader(unittest.TestCase):
         tmp_dir = tempfile.gettempdir()
 
         num_files_before = len(os.listdir(tmp_dir))
-        with DwCAReader(BASIC_ARCHIVE_PATH):
+        with DwCAReader(sample_data_path('dwca-simple-test-archive.zip')):
             num_files_during = len(os.listdir(tmp_dir))
 
         self.assertEqual(num_files_before, num_files_during - 1)
@@ -557,14 +552,14 @@ class TestDwCAReader(unittest.TestCase):
     def test_no_temporary_dir_directory(self):
         """If archive is a directory, no need to create temporary files."""
         num_files_before = len(os.listdir('.'))
-        with DwCAReader(DIRECTORY_ARCHIVE_PATH):
+        with DwCAReader(sample_data_path('dwca-simple-dir')):
             num_files_during = len(os.listdir('.'))
 
         self.assertEqual(num_files_before, num_files_during)
 
     def test_archives_without_metadata(self):
         """Ensure we can deal with an archive containing a metafile, but no metadata."""
-        with DwCAReader(NOMETADATA_PATH) as dwca:
+        with DwCAReader(sample_data_path('dwca-nometadata.zip')) as dwca:
             self.assertIsNone(dwca.metadata)
 
             # But the data is nevertheless accessible
@@ -574,11 +569,8 @@ class TestDwCAReader(unittest.TestCase):
             self.assertEqual('Mumbai', rows[1].data[qn('locality')])
 
     def test_metadata(self):
-        """A few basic tests on the metadata attribute
-
-        TODO: split
-        """
-        with DwCAReader(BASIC_ARCHIVE_PATH) as dwca:
+        """A few basic tests on the metadata attribute."""
+        with DwCAReader(sample_data_path('dwca-simple-test-archive.zip')) as dwca:
             # Assert metadata is an instance of ElementTree.Element
             self.assertIsInstance(dwca.metadata, ET.Element)
 
@@ -590,40 +582,40 @@ class TestDwCAReader(unittest.TestCase):
     def test_core_contains_term(self):
         """Test the core_contains_term method."""
         # Example file contains locality but no country
-        with DwCAReader(BASIC_ARCHIVE_PATH) as dwca:
+        with DwCAReader(sample_data_path('dwca-simple-test-archive.zip')) as dwca:
             self.assertTrue(dwca.core_contains_term(qn('locality')))
             self.assertFalse(dwca.core_contains_term(qn('country')))
 
         # Also test it with a simple (= no metafile) archive
-        with DwCAReader(SIMPLE_CSV) as dwca:
+        with DwCAReader(sample_data_path('dwca-simple-csv.zip')) as dwca:
             self.assertTrue(dwca.core_contains_term('datasetkey'))
             self.assertFalse(dwca.core_contains_term('trucmachin'))
 
     def test_ignore_header_lines(self):
-        with DwCAReader(BASIC_ARCHIVE_PATH) as dwca:
+        with DwCAReader(sample_data_path('dwca-simple-test-archive.zip')) as dwca:
             # The sample file has two real rows + 1 header line
             self.assertEqual(2, len([l for l in dwca]))
 
-        with DwCAReader(NOHEADERS1_PATH) as dwca:
+        with DwCAReader(sample_data_path('dwca-noheaders-1.zip')) as dwca:
             # This file has two real rows, without headers
             # (specified in meta.xml)
             self.assertEqual(2, len([l for l in dwca]))
 
-        with DwCAReader(NOHEADERS2_PATH) as dwca:
+        with DwCAReader(sample_data_path('dwca-noheaders-2.zip')) as dwca:
             # This file has two real rows, without headers
             # (nothing specified in meta.xml)
             self.assertEqual(2, len([l for l in dwca]))
 
     def test_iterate_rows(self):
         """Test the iterating over CoreRow(s)"""
-        with DwCAReader(BASIC_ARCHIVE_PATH) as dwca:
+        with DwCAReader(sample_data_path('dwca-simple-test-archive.zip')) as dwca:
             for row in dwca:
                 self.assertIsInstance(row, CoreRow)
 
     def test_iterate_order(self):
         """Test that the order of appearance in Core file is respected when iterating."""
         # This is also probably tested indirectly elsewhere, but this is the right place :)
-        with DwCAReader(IDS_ARCHIVE_PATH) as dwca:
+        with DwCAReader(sample_data_path('dwca-ids.zip')) as dwca:
             l = list(dwca)
             # Row IDs are ordered like this in core file: id 4-1-3-2
             self.assertEqual(int(l[0].id), 4)
@@ -632,7 +624,7 @@ class TestDwCAReader(unittest.TestCase):
             self.assertEqual(int(l[3].id), 2)
 
     def test_iterate_multiple_calls(self):
-        with DwCAReader(MULTIEXTENSIONS_ARCHIVE_PATH) as dwca:
+        with DwCAReader(sample_data_path('dwca-2extensions.zip')) as dwca:
             self.assertEqual(4, len([l for l in dwca]))
             # The second time, we can still find 4 rows...
             self.assertEqual(4, len([l for l in dwca]))
@@ -643,7 +635,7 @@ class TestDwCAReader(unittest.TestCase):
         with warnings.catch_warnings(record=True) as w:
             warnings.simplefilter("always", DeprecationWarning)
 
-            with DwCAReader(IDS_ARCHIVE_PATH) as dwca:
+            with DwCAReader(sample_data_path('dwca-ids.zip')) as dwca:
                 # Passed as an integer, conversion will be tried...
                 r = dwca.get_row_by_id(3)
                 self.assertEqual('Peliperdix', r.data['http://rs.tdwg.org/dwc/terms/genus'])
@@ -660,7 +652,7 @@ class TestDwCAReader(unittest.TestCase):
             warnings.simplefilter("always", DeprecationWarning)
 
             # Copy-pasted code from the long term test_get_corerow_by_position()
-            with DwCAReader(IDS_ARCHIVE_PATH) as dwca:
+            with DwCAReader(sample_data_path('dwca-ids.zip')) as dwca:
                 # Row IDs are ordered like this in core: id 4-1-3-2
                 first_row = dwca.get_row_by_index(0)
                 self.assertEqual(4, int(first_row.id))
@@ -682,7 +674,7 @@ class TestDwCAReader(unittest.TestCase):
 
     def test_get_corerow_by_position(self):
         """Test the get_corerow_by_position() method work as expected"""
-        with DwCAReader(IDS_ARCHIVE_PATH) as dwca:
+        with DwCAReader(sample_data_path('dwca-ids.zip')) as dwca:
             # Row IDs are ordered like this in core: id 4-1-3-2
             first_row = dwca.get_corerow_by_position(0)
             self.assertEqual(4, int(first_row.id))
@@ -700,7 +692,7 @@ class TestDwCAReader(unittest.TestCase):
     def test_get_corerow_by_id_string(self):
         genus_qn = 'http://rs.tdwg.org/dwc/terms/genus'
 
-        with DwCAReader(IDS_ARCHIVE_PATH) as dwca:
+        with DwCAReader(sample_data_path('dwca-ids.zip')) as dwca:
             # Number can be passed as a string....
             r = dwca.get_corerow_by_id('3')
             self.assertEqual('Peliperdix', r.data[genus_qn])
@@ -708,7 +700,7 @@ class TestDwCAReader(unittest.TestCase):
     def test_get_corerow_by_id_multiple_calls(self):
         genus_qn = 'http://rs.tdwg.org/dwc/terms/genus'
 
-        with DwCAReader(IDS_ARCHIVE_PATH) as dwca:
+        with DwCAReader(sample_data_path('dwca-ids.zip')) as dwca:
             r = dwca.get_corerow_by_id('3')
             self.assertEqual('Peliperdix', r.data[genus_qn])
 
@@ -720,20 +712,20 @@ class TestDwCAReader(unittest.TestCase):
     def test_get_corerow_by_id_other(self):
         genus_qn = 'http://rs.tdwg.org/dwc/terms/genus'
 
-        with DwCAReader(IDS_ARCHIVE_PATH) as dwca:
+        with DwCAReader(sample_data_path('dwca-ids.zip')) as dwca:
             # Passed as an integer, conversion will be tried...
             r = dwca.get_corerow_by_id(3)
             self.assertEqual('Peliperdix', r.data[genus_qn])
 
     def test_get_inexistent_row(self):
         """ Ensure get_corerow_by_id() raises RowNotFound if we ask it an unexistent row. """
-        with DwCAReader(IDS_ARCHIVE_PATH) as dwca:
+        with DwCAReader(sample_data_path('dwca-ids.zip')) as dwca:
             with self.assertRaises(RowNotFound):
                 dwca.get_corerow_by_id(8000)
 
     def test_read_core_value(self):
         """Retrieve a simple value from core file"""
-        with DwCAReader(BASIC_ARCHIVE_PATH) as dwca:
+        with DwCAReader(sample_data_path('dwca-simple-test-archive.zip')) as dwca:
             rows = list(dwca)
 
             # Check basic locality values from sample file
@@ -742,7 +734,7 @@ class TestDwCAReader(unittest.TestCase):
 
     def test_enclosed_data(self):
         """Ensure data is properly trimmed when fieldsEnclosedBy is in use."""
-        with DwCAReader(BASIC_ENCLOSED_ARCHIVE_PATH) as dwca:
+        with DwCAReader(sample_data_path('dwca-simple-test-archive-enclosed.zip')) as dwca:
             rows = list(dwca)
 
             # Locality is enclosed in "'" chars, they should be trimmed...
@@ -761,7 +753,7 @@ class TestDwCAReader(unittest.TestCase):
         text file. This is part of the standard and was produced by IPT
         prior to version 2.0.3.
         """
-        with DwCAReader(DEFAULT_VAL_PATH) as dwca:
+        with DwCAReader(sample_data_path('dwca-test-default.zip')) as dwca:
             for l in dwca:
                 self.assertEqual('Belgium', l.data[qn('country')])
 
@@ -782,7 +774,7 @@ class TestDwCAReader(unittest.TestCase):
         # We know we have no \n in our test archive, so if we fine one
         # it's probably a character that was left by error when parsing
         # line
-        with DwCAReader(BASIC_ARCHIVE_PATH) as simple_dwca:
+        with DwCAReader(sample_data_path('dwca-simple-test-archive.zip')) as simple_dwca:
             for l in simple_dwca:
                 for k, v in l.data.items():
                     self.assertFalse(v.endswith("\n"))
@@ -791,11 +783,11 @@ class TestDwCAReader(unittest.TestCase):
         """Test we have the correct number of extensions rows."""
 
         # This one has no extension, so row.extensions should be an empty list
-        with DwCAReader(BASIC_ARCHIVE_PATH) as simple_dwca:
+        with DwCAReader(sample_data_path('dwca-simple-test-archive.zip')) as simple_dwca:
             for r in simple_dwca:
                 self.assertEqual(0, len(r.extensions))
 
-        with DwCAReader(EXTENSION_ARCHIVE_PATH) as star_dwca:
+        with DwCAReader(sample_data_path('dwca-star-test-archive.zip')) as star_dwca:
             rows = list(star_dwca)
 
             # 3 vernacular names are given for Struthio Camelus...
@@ -807,7 +799,7 @@ class TestDwCAReader(unittest.TestCase):
             self.assertEqual(0, len(rows[3].extensions))
 
         # TODO: test the same thing with 2 different extensions reffering to the row
-        with DwCAReader(MULTIEXTENSIONS_ARCHIVE_PATH) as multi_dwca:
+        with DwCAReader(sample_data_path('dwca-2extensions.zip')) as multi_dwca:
             rows = list(multi_dwca)
 
             # 3 vernacular names + 2 taxon descriptions
@@ -822,7 +814,7 @@ class TestDwCAReader(unittest.TestCase):
         """Ensure the extensions_to_ignore argument work as expected."""
 
         # This archive has two extensions, but we ask to ignore one...
-        with DwCAReader(MULTIEXTENSIONS_ARCHIVE_PATH,
+        with DwCAReader(sample_data_path('dwca-2extensions.zip'),
                         extensions_to_ignore="description.txt") as multi_dwca:
 
             rows = list(multi_dwca)
@@ -835,7 +827,7 @@ class TestDwCAReader(unittest.TestCase):
             self.assertEqual(0, len(rows[2].extensions))
 
         # Here, we ignore the only extension of an archive
-        with DwCAReader(EXTENSION_ARCHIVE_PATH,
+        with DwCAReader(sample_data_path('dwca-star-test-archive.zip'),
                         extensions_to_ignore="vernacularname.txt") as star_dwca:
                 rows = list(star_dwca)
 
@@ -846,7 +838,7 @@ class TestDwCAReader(unittest.TestCase):
 
         # And here, we check it is silently ignored and everything works in case we ask to
         # ignore an unexisting extension
-        with DwCAReader(MULTIEXTENSIONS_ARCHIVE_PATH,
+        with DwCAReader(sample_data_path('dwca-2extensions.zip'),
                         extensions_to_ignore="helloworld.txt") as multi_dwca:
 
             rows = list(multi_dwca)
@@ -860,7 +852,7 @@ class TestDwCAReader(unittest.TestCase):
 
     def test_row_rowtype(self):
         """Test the rowtype attribute of rows (for Core and extensions)."""
-        with DwCAReader(EXTENSION_ARCHIVE_PATH) as star_dwca:
+        with DwCAReader(sample_data_path('dwca-star-test-archive.zip')) as star_dwca:
             taxon_qn = "http://rs.tdwg.org/dwc/terms/Taxon"
             vernacular_qn = "http://rs.gbif.org/terms/1.0/VernacularName"
 
@@ -873,7 +865,7 @@ class TestDwCAReader(unittest.TestCase):
                     self.assertEqual(vernacular_qn, row.extensions[0].rowtype)
 
     def test_row_class(self):
-        with DwCAReader(EXTENSION_ARCHIVE_PATH) as star_dwca:
+        with DwCAReader(sample_data_path('dwca-star-test-archive.zip')) as star_dwca:
             for row in star_dwca:
                 self.assertIsInstance(row, CoreRow)
 
@@ -888,7 +880,7 @@ class TestDwCAReader(unittest.TestCase):
         The content of this 'rows' property is equivalent to iterating and
         storing result in a list.
         """
-        with DwCAReader(EXTENSION_ARCHIVE_PATH) as star_dwca:
+        with DwCAReader(sample_data_path('dwca-star-test-archive.zip')) as star_dwca:
             by_iteration = []
             for r in star_dwca:
                 by_iteration.append(r)
@@ -905,7 +897,7 @@ class TestDwCAReader(unittest.TestCase):
         (only the EOL string specified in meta.xml should be used).
          """
 
-        with DwCAReader(UTF8EOL_ARCHIVE_PATH) as dwca:
+        with DwCAReader(sample_data_path('dwca-utf8-eol-test.zip')) as dwca:
             rows = dwca.rows
             # If line properly split => 64 columns.
             # (61 - and probably an IndexError - if errors)
@@ -913,11 +905,11 @@ class TestDwCAReader(unittest.TestCase):
 
     def test_source_metadata(self):
         # Standard archive: no source metadata
-        with DwCAReader(EXTENSION_ARCHIVE_PATH) as star_dwca:
+        with DwCAReader(sample_data_path('dwca-star-test-archive.zip')) as star_dwca:
             self.assertEqual(star_dwca.source_metadata, {})
 
         # GBIF download: source metadata present
-        with DwCAReader(GBIF_RESULTS_PATH) as results:
+        with DwCAReader(sample_data_path('gbif-results.zip')) as results:
             # We have 23 EML files in the dataset directory
             self.assertEqual(23, len(results.source_metadata))
             # Assert a key is present
@@ -941,12 +933,12 @@ class TestDwCAReader(unittest.TestCase):
     def test_row_source_metadata(self):
         # For normal DwC-A, it should always be None (NO source data
         # available in archive.)
-        with DwCAReader(EXTENSION_ARCHIVE_PATH) as star_dwca:
+        with DwCAReader(sample_data_path('dwca-star-test-archive.zip')) as star_dwca:
             self.assertIsNone(star_dwca.rows[0].source_metadata)
 
         # But it should be supported for GBIF-originating archives
         # (was previously supported with GBIFResultsReader)
-        with DwCAReader(GBIF_RESULTS_PATH) as results:
+        with DwCAReader(sample_data_path('gbif-results.zip')) as results:
             first_row = results.get_corerow_by_id('607759330')
             m = first_row.source_metadata
 
@@ -977,19 +969,19 @@ class TestDwCAReader(unittest.TestCase):
     def test_orphaned_extension_rows_noext(self):
         """ orphaned_extension_rows returns {} when there's no extensions."""
         # Archive without extensions: we expect {}
-        with DwCAReader(BASIC_ARCHIVE_PATH) as dwca:
+        with DwCAReader(sample_data_path('dwca-simple-test-archive.zip')) as dwca:
             self.assertEqual({}, dwca.orphaned_extension_rows())
 
     def test_orphaned_extension_rows_no_orphans(self):
         # Archive with extensions, but no orphaned extension rows
 
-        with DwCAReader(MULTIEXTENSIONS_ARCHIVE_PATH) as dwca:
+        with DwCAReader(sample_data_path('dwca-2extensions.zip')) as dwca:
             expected = {'description.txt': {}, 'vernacularname.txt': {}}
             self.assertEqual(expected, dwca.orphaned_extension_rows())
 
     def test_orphaned_extension_rows(self):
         # Archive with extensions and orphaned rows
-        with DwCAReader(DWCA_ORPHANED_ROWS) as dwca:
+        with DwCAReader(sample_data_path('dwca-orphaned-rows.zip')) as dwca:
             expected = {
                 'description.txt': {u'5': [3, 4], u'6': [5]},
                 'vernacularname.txt': {u'7': [4]}
